"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.get_flash_growth = exports.get_flash_dfuse = exports.get_flash = void 0;
const dfuse_1 = require("./dfuse");
const utils_1 = require("./utils");
async function get_flash(rpc) {
    const code = "stats.sx";
    const scope = code;
    const table = "flash";
    const results = await rpc.get_table_rows({ json: true, code, scope, table, limit: 1, lower_bound: "flash.sx", upper_bound: "flash.sx" });
    return results.rows[0];
}
exports.get_flash = get_flash;
async function get_flash_dfuse(client, block_num) {
    return dfuse_1.stateTableRow(client, "stats.sx", "stats.sx", "flash", "flash.sx", block_num);
}
exports.get_flash_dfuse = get_flash_dfuse;
async function get_flash_growth(client, symcode, block_num, block_num_delta = 172800) {
    const block_num_previous = block_num - block_num_delta;
    const flash = await get_flash_dfuse(client, block_num);
    const previous_flash = await get_flash_dfuse(client, block_num_previous);
    // calculate borrow
    const borrow_delta = utils_1.numberFromMap(flash.borrow, symcode) - utils_1.numberFromMap(previous_flash.borrow, symcode);
    const fees_delta = utils_1.numberFromMap(flash.fees, symcode) - utils_1.numberFromMap(previous_flash.fees, symcode);
    const reserves_delta = utils_1.numberFromMap(flash.reserves, symcode) - utils_1.numberFromMap(previous_flash.reserves, symcode);
    const transactions_delta = flash.transactions - previous_flash.transactions;
    return {
        // block information
        block_num,
        block_num_previous,
        block_num_delta,
        // contract values
        contract: flash.contract,
        last_modified: flash.last_modified,
        transactions: flash.transactions,
        borrow: flash.borrow,
        fees: flash.fees,
        reserves: flash.reserves,
        // 24h computed values
        borrow_delta,
        fees_delta,
        reserves_delta,
        transactions_delta,
    };
}
exports.get_flash_growth = get_flash_growth;
