"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.get_usdx_growth = exports.get_usdx_dfuse = exports.get_usdx = void 0;
const dfuse_1 = require("./dfuse");
const utils_1 = require("./utils");
async function get_usdx(rpc) {
    const code = "usdx.sx";
    const scope = code;
    const table = "liquidity";
    const results = await rpc.get_table_rows({ json: true, code, scope, table, limit: 1 });
    return results.rows[0];
}
exports.get_usdx = get_usdx;
async function get_usdx_dfuse(client, block_num) {
    return dfuse_1.stateTable(client, "usdx.sx", "usdx.sx", "liquidity", block_num);
}
exports.get_usdx_dfuse = get_usdx_dfuse;
// TEMP
function get_total(usdx) {
    return usdx.total || usdx.deposit || 0;
}
async function get_usdx_growth(client, block_num, block_num_delta = 172800) {
    const block_num_previous = block_num - block_num_delta;
    const usdx = await get_usdx_dfuse(client, block_num);
    const usdx_previous = await get_usdx_dfuse(client, block_num_previous);
    // total value locked growth
    const tvl = get_total(usdx) / 10000;
    const tvl_previous = (usdx_previous.deposit || usdx_previous.total || 0) / 10000;
    const tvl_growth = tvl - tvl_previous;
    const staked = (usdx.staked || 0) / 10000;
    // value per share APY
    const virtual_price = usdx.virtual_price || get_total(usdx) / utils_1.toNumber(usdx.supply.quantity);
    const virtual_price_previous = usdx_previous.virtual_price || get_total(usdx_previous) / utils_1.toNumber(usdx_previous.supply.quantity) / 10000;
    const virtual_price_growth = (virtual_price - virtual_price_previous) / virtual_price;
    // price delta changes
    const price0_delta = (usdx.price0 - usdx_previous.price0) / usdx.price0;
    const price1_delta = (usdx.price1 - usdx_previous.price1) / usdx.price1;
    // calculate growth
    const growth_price0 = price0_delta * utils_1.toNumber(usdx.reserve0.quantity) * usdx.price0;
    const growth_price1 = price1_delta * utils_1.toNumber(usdx.reserve1.quantity) * usdx.price1;
    const growth_price = growth_price0 + growth_price1;
    const growth_claim = staked * virtual_price_growth - growth_price; // approximate growth based on virtual growth minus price delta
    const growth = growth_price + growth_claim;
    // calculate APY
    const average_tvl = (tvl_previous + tvl) / 2;
    const apy_average_revenue = growth_claim * 365 / average_tvl;
    const apy_realtime_revenue = growth_claim * 365 / tvl;
    // additional metrics
    const exposure = utils_1.toNumber(usdx.reserve0.quantity) * usdx.price0 / get_total(usdx) * 10000;
    return {
        // block information
        block_num,
        block_num_previous,
        block_num_delta,
        // contract values
        contract: usdx.contract,
        mid: usdx.mid,
        reserve0: usdx.reserve0,
        reserve1: usdx.reserve1,
        supply: usdx.supply,
        price0: usdx.price0,
        price1: usdx.price1,
        liquid: usdx.liquid,
        staked: usdx.staked,
        total: get_total(usdx),
        last_updated: usdx.last_updated,
        virtual_price: usdx.virtual_price,
        // 24h computed values
        apy_average_revenue,
        apy_realtime_revenue,
        tvl,
        tvl_growth,
        growth_claim,
        growth_price,
        growth,
        virtual_price_growth,
        price0_delta,
        price1_delta,
        exposure
    };
}
exports.get_usdx_growth = get_usdx_growth;
